#ifndef NT2_INCLUDE_FUNCTIONS_FUZZY_DEFINITELY_GREATER_HPP_INCLUDED
#define NT2_INCLUDE_FUNCTIONS_FUZZY_DEFINITELY_GREATER_HPP_INCLUDED

#include <nt2/fuzzy/include/functions/fuzzy_definitely_greater.hpp>

#endif
